@@ -1,4 +1,5 @@
 import re
+import pkgutil
 
 from mkdocs.plugins import BasePlugin
 
@@ -13,9 +14,8 @@ class LinkPreviewPlugin(BasePlugin):
         self.preview_template = None
 
     def on_config(self, config):
-        template_file = open("resources/preview.html", 'r')
-        self.preview_template = template_file.read()
-        template_file.close()
+        template_file = pkgutil.get_data(__name__, "resources/preview.html")
+        self.preview_template = template_file
         return config
 
     def on_page_markdown(self, markdown, page, config, files):
